@@ -1,6 +1,6 @@
 package Term::FormatColumns;
 {
-  $Term::FormatColumns::VERSION = '0.004';
+  $Term::FormatColumns::VERSION = '0.005';
 }
 
 use Sub::Exporter -setup => [
@@ -16,7 +16,7 @@ use POSIX qw( ceil );
 use Symbol qw(qualify_to_ref);
 
 sub format_columns(@) {
-    return format_columns_for_fh STDOUT, @_;
+    return format_columns_for_fh( STDOUT, @_ );
 }
 
 sub format_columns_for_fh(*@) {
